Documentation
¶
Overview ¶
Package param contains the Param interface.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func MayTakeValue ¶
MayTakeValue returns true if the Param was constructed with something other than a *bool.
func MustTakeValue ¶
MustTakeValue returns true if the Param was constructed with something other than a *bool or a pointer to a pointer type.
Types ¶
type Param ¶
Param is the interface that all custom config struct field types must satisfy.
See Run for more details on how Param is used.
As a high-level recommendation, note that you usually want to implement Param by taking a pointer receiver; Set should typically mutate the inner value of your Param implementation.
Click to show internal directories.
Click to hide internal directories.